==> doxygen-docs-1.8.14-1-armv7h.pkg.tar.xz: usr/share/doc/doxygen/html/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"docblocks.html#docexamples":[2,0,0,1],
"docblocks.html#docstructure":[2,1],
"docblocks.html#fortranblocks":[2,0,3],
"docblocks.html#memberdoc":[2,0,0,0],
"docblocks.html#pythonblocks":[2,0,1],
"docblocks.html#specialblock":[2,0],
"docblocks.html#structuralcommands":[2,0,0,2],
"docblocks.html#tclblocks":[2,0,4],
"docblocks.html#vhdlblocks":[2,0,2],
"doxygen_usage.html":[19],
"doxygen_usage.html#doxygen_finetune":[19,0],
"doxywizard_usage.html":[20],
"external.html":[15],
"extsearch.html":[12,0],
"extsearch.html#extsearch_api":[12,0,3],
"extsearch.html#extsearch_api_index":[12,0,3,0],
"extsearch.html#extsearch_api_search_in":[12,0,3,1],
"extsearch.html#extsearch_api_search_out":[12,0,3,2],
"extsearch.html#extsearch_config":[12,0,1],
"extsearch.html#extsearch_intro":[12,0,0],
"extsearch.html#extsearch_multi":[12,0,1,1],
"extsearch.html#extsearch_single":[12,0,1,0],
"extsearch.html#extsearch_update":[12,0,2],
"faq.html":[16],
"faq.html#fac_al":[16,1],
"faq.html#faq_chm":[16,6],
"faq.html#faq_class":[16,11],
"faq.html#faq_cmdline":[16,17],
"faq.html#faq_code":[16,4],
"faq.html#faq_code_inc":[16,5],
"faq.html#faq_excl_dir":[16,10],
"faq.html#faq_ext_mapping":[16,3],
"faq.html#faq_extract_all":[16,2],
"faq.html#faq_html":[16,7],
"faq.html#faq_html_header":[16,8],
"faq.html#faq_index":[16,0],
"faq.html#faq_latex":[16,14],
"faq.html#faq_lex":[16,13],
"faq.html#faq_name":[16,18],
"faq.html#faq_pgm_X":[16,12],
"faq.html#faq_search":[16,16],
"faq.html#faq_stl":[16,15],
"faq.html#faq_use_qt":[16,9],
"faq.html#faq_why":[16,19],
"features.html":[18],
"formulas.html":[6],
"grouping.html":[5],
"grouping.html#memgroup":[5,1],
"grouping.html#modules":[5,0],
"grouping.html#subpaging":[5,2],
"htmlcmds.html":[23],
"index.html":[],
"install.html":[0],
"install.html#install_bin_unix":[0,1],
"install.html#install_bin_windows":[0,3],
"install.html#install_src_unix":[0,0],
"install.html#install_src_windows":[0,2],
"langhowto.html":[25],
"lists.html":[4],
"markdown.html":[3],
"markdown.html#markdown_debug":[3,3],
"markdown.html#markdown_dox":[3,2],
"markdown.html#markdown_extra":[3,1],
"markdown.html#markdown_std":[3,0],
"markdown.html#md_autolink":[3,0,10],
"markdown.html#md_blockquotes":[3,0,2],
"markdown.html#md_codeblock":[3,0,4],
"markdown.html#md_codespan":[3,0,7],
"markdown.html#md_emphasis":[3,0,6],
"markdown.html#md_fenced":[3,1,2],
"markdown.html#md_header_id":[3,1,3],
"markdown.html#md_headers":[3,0,1],
"markdown.html#md_html_blocks":[3,2,1],
"markdown.html#md_images":[3,0,9],
"markdown.html#md_inlinelinks":[3,0,8,0],
"markdown.html#md_links":[3,0,8],
"markdown.html#md_lists":[3,0,3],
"markdown.html#md_page_header":[3,2,0],
"markdown.html#md_para":[3,0,0],
"markdown.html#md_reflinks":[3,0,8,1],
"markdown.html#md_rulers":[3,0,5],
"markdown.html#md_tables":[3,1,1],
"markdown.html#md_toc":[3,1,0],
"markdown.html#mddox_code_blocks":[3,2,2],
"markdown.html#mddox_code_spans":[3,2,4],
"markdown.html#mddox_emph_spans":[3,2,3],
"markdown.html#mddox_limits":[3,2,7],
"markdown.html#mddox_lists":[3,2,5],
"markdown.html#mddox_stars":[3,2,6],
"output.html":[11],
"pages.html":[],
"perlmod.html":[26],
"perlmod.html#doxydocs_format":[26,2],
"perlmod.html#doxymodel_format":[26,3],
"perlmod.html#perlmod_latex":[26,1],
"perlmod.html#pm_pdf_gen":[26,1,0],
"perlmod.html#using_perlmod_fmt":[26,0],
"perlmod_tree.html":[27],
"preprocessing.html":[9],
"searching.html":[12],
"starting.html":[1],
"starting.html#docbook_out":[1,2,5],
"starting.html#html_out":[1,2,0],
"starting.html#latex_out":[1,2,1],
"starting.html#man_out":[1,2,4],
"starting.html#rtf_out":[1,2,2],
"starting.html#step0":[1,0],
"starting.html#step1":[1,1],
"starting.html#step2":[1,2],
"starting.html#step3":[1,3],
"starting.html#xml_out":[1,2,3],
"tables.html":[7],
"trouble.html":[17],
"trouble.html#bug_reports":[17,2],
"trouble.html#howtohelp":[17,1],
"trouble.html#knowproblems":[17,0],
"xmlcmds.html":[24]
};

==> doxygen-docs-1.8.18-1-armv7h.pkg.tar.xz: usr/share/doc/doxygen/html/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"config.html#config_preprocessor":[21,15],
"config.html#config_project":[21,1],
"config.html#config_rtf":[21,9],
"config.html#config_source_browser":[21,5],
"config.html#config_xml":[21,11],
"custcmd.html":[14],
"custcmd.html#custcmd_complex":[14,1],
"custcmd.html#custcmd_nesting":[14,2],
"custcmd.html#custcmd_simple":[14,0],
"customize.html":[13],
"customize.html#layout":[13,1],
"customize.html#minor_tweaks":[13,0],
"customize.html#minor_tweaks_colors":[13,0,0],
"customize.html#minor_tweaks_dynsection":[13,0,2],
"customize.html#minor_tweaks_header_css":[13,0,3],
"customize.html#minor_tweaks_treeview":[13,0,1],
"customize.html#xmlgenerator":[13,2],
"diagrams.html":[8],
"docblocks.html":[2],
"docblocks.html#cppblock":[2,0,0],
"docblocks.html#docexamples":[2,0,0,1],
"docblocks.html#docstructure":[2,1],
"docblocks.html#fortranblocks":[2,0,3],
"docblocks.html#memberdoc":[2,0,0,0],
"docblocks.html#pythonblocks":[2,0,1],
"docblocks.html#specialblock":[2,0],
"docblocks.html#structuralcommands":[2,0,0,2],
"docblocks.html#vhdlblocks":[2,0,2],
"doxygen_usage.html":[19],
"doxygen_usage.html#doxygen_finetune":[19,0],
"doxywizard_usage.html":[20],
"emojisup.html":[25],
"emojisup.html#emojiimage":[25,1],
"emojisup.html#emojirep":[25,0],
"external.html":[15],
"extsearch.html":[12,0],
"extsearch.html#extsearch_api":[12,0,3],
"extsearch.html#extsearch_api_index":[12,0,3,0],
"extsearch.html#extsearch_api_search_in":[12,0,3,1],
"extsearch.html#extsearch_api_search_out":[12,0,3,2],
"extsearch.html#extsearch_config":[12,0,1],
"extsearch.html#extsearch_intro":[12,0,0],
"extsearch.html#extsearch_multi":[12,0,1,1],
"extsearch.html#extsearch_single":[12,0,1,0],
"extsearch.html#extsearch_update":[12,0,2],
"faq.html":[16],
"faq.html#fac_al":[16,1],
"faq.html#faq_chm":[16,6],
"faq.html#faq_class":[16,11],
"faq.html#faq_cmdline":[16,17],
"faq.html#faq_code":[16,4],
"faq.html#faq_code_inc":[16,5],
"faq.html#faq_excl_dir":[16,10],
"faq.html#faq_ext_mapping":[16,3],
"faq.html#faq_extract_all":[16,2],
"faq.html#faq_html":[16,7],
"faq.html#faq_html_header":[16,8],
"faq.html#faq_index":[16,0],
"faq.html#faq_latex":[16,14],
"faq.html#faq_lex":[16,13],
"faq.html#faq_name":[16,18],
"faq.html#faq_pgm_X":[16,12],
"faq.html#faq_search":[16,16],
"faq.html#faq_stl":[16,15],
"faq.html#faq_use_qt":[16,9],
"faq.html#faq_why":[16,19],
"features.html":[18],
"formulas.html":[6],
"grouping.html":[5],
"grouping.html#memgroup":[5,1],
"grouping.html#modules":[5,0],
"grouping.html#subpaging":[5,2],
"htmlcmds.html":[23],
"index.html":[],
"install.html":[0],
"install.html#install_bin_unix":[0,1],
"install.html#install_bin_windows":[0,3],
"install.html#install_src_unix":[0,0],
"install.html#install_src_windows":[0,2],
"langhowto.html":[26],
"lists.html":[4],
"markdown.html":[3],
"markdown.html#markdown_debug":[3,3],
"markdown.html#markdown_dox":[3,2],
"markdown.html#markdown_extra":[3,1],
"markdown.html#markdown_std":[3,0],
"markdown.html#md_autolink":[3,0,11],
"markdown.html#md_blockquotes":[3,0,2],
"markdown.html#md_codeblock":[3,0,4],
"markdown.html#md_codespan":[3,0,8],
"markdown.html#md_emphasis":[3,0,6],
"markdown.html#md_fenced":[3,1,2],
"markdown.html#md_header_id":[3,1,3],
"markdown.html#md_headers":[3,0,1],
"markdown.html#md_html_blocks":[3,2,1],
"markdown.html#md_images":[3,0,10],
"markdown.html#md_inlinelinks":[3,0,9,0],
"markdown.html#md_links":[3,0,9],
"markdown.html#md_lists":[3,0,3],
"markdown.html#md_page_header":[3,2,0],
"markdown.html#md_para":[3,0,0],
"markdown.html#md_reflinks":[3,0,9,1],
"markdown.html#md_rulers":[3,0,5],
"markdown.html#md_strikethrough":[3,0,7],
"markdown.html#md_tables":[3,1,1],
"markdown.html#md_toc":[3,1,0],
"markdown.html#mddox_code_blocks":[3,2,2],
"markdown.html#mddox_code_spans":[3,2,4],
"markdown.html#mddox_emph_spans":[3,2,3],
"markdown.html#mddox_limits":[3,2,7],
"markdown.html#mddox_lists":[3,2,5],
"markdown.html#mddox_stars":[3,2,6],
"output.html":[11],
"pages.html":[],
"perlmod.html":[27],
"perlmod.html#doxydocs_format":[27,2],
"perlmod.html#doxymodel_format":[27,3],
"perlmod.html#perlmod_latex":[27,1],
"perlmod.html#pm_pdf_gen":[27,1,0],
"perlmod.html#using_perlmod_fmt":[27,0],
"perlmod_tree.html":[28],
"preprocessing.html":[9],
"searching.html":[12],
"starting.html":[1],
"starting.html#docbook_out":[1,2,5],
"starting.html#html_out":[1,2,0],
"starting.html#latex_out":[1,2,1],
"starting.html#man_out":[1,2,4],
"starting.html#rtf_out":[1,2,2],
"starting.html#step0":[1,0],
"starting.html#step1":[1,1],
"starting.html#step2":[1,2],
"starting.html#step3":[1,3],
"starting.html#xml_out":[1,2,3],
"tables.html":[7],
"trouble.html":[17],
"trouble.html#bug_reports":[17,2],
"trouble.html#howtohelp":[17,1],
"trouble.html#knowproblems":[17,0],
"xmlcmds.html":[24]
};
